==> s-render-0.2.3.tgz: package/es/FormRender/widgets/container/BoxCard.js <==
import "antd/es/row/style";
import _Row from "antd/es/row";
import "antd/es/card/style";
import _Card from "antd/es/card";
var _templateObject, _templateObject2;
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }
import { useContext } from 'react';
import { css, styled } from 'styled-components';
import { ConfigContext } from "../../../FormRender/models/context";
import { jsx as _jsx } from "react/jsx-runtime";
var CardWrapper = styled(_Card)(_templateObject || (_templateObject = _taggedTemplateLiteral(["\n  .ant-card-head {\n    ", "\n  }\n  .ant-card-body {\n    // margin-bottom: -24px;\n  }\n"])), function (props) {
  return props['data-primary'] && css(_templateObject2 || (_templateObject2 = _taggedTemplateLiteral(["\n        background-color: ", ";\n        color: #fff;\n      "])), props['data-primary']);
});
export default (function (props) {
  var schema = props.schema,
    renderCore = props.renderCore,
    rootPath = props.rootPath,
    path = props.path,
    children = props.children;
  var _useContext = useContext(ConfigContext),
    themeConfig = _useContext.themeConfig;
  return /*#__PURE__*/_jsx(CardWrapper, {
    title: schema === null || schema === void 0 ? void 0 : schema.title,
    size: "small",
    "data-primary": themeConfig.colorPrimary,
    children: /*#__PURE__*/_jsx(_Row, {
      gutter: 18,
      children: children ? children : renderCore({
        schema: schema.properties,
        rootPath: [].concat(_toConsumableArray(rootPath), [path])
      })
    })
  });
});

==> s-render-0.2.5.tgz: package/es/FormRender/widgets/container/BoxCard.js <==
import "antd/es/card/style";
import _Card from "antd/es/card";
import "antd/es/row/style";
import _Row from "antd/es/row";
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
import { useContext } from 'react';
import { ConfigContext } from "../../../FormRender/models/context";

// const CardWrapper = styled(Card)`
//   .ant-card-head {
//     ${(props: any) =>
//       props['data-primary'] &&
//       css`
//         background-color: ${props['data-primary']};
//         color: #fff;
//       `}
//   }
//   .ant-card-body {
//     // margin-bottom: -24px;
//   }
// `;
import { jsx as _jsx } from "react/jsx-runtime";
export default (function (props) {
  var schema = props.schema,
    renderCore = props.renderCore,
    rootPath = props.rootPath,
    path = props.path,
    children = props.children;
  var _useContext = useContext(ConfigContext),
    themeConfig = _useContext.themeConfig;
  return /*#__PURE__*/_jsx(_Card, {
    title: schema === null || schema === void 0 ? void 0 : schema.title,
    size: "small",
    "data-primary": themeConfig.colorPrimary,
    children: /*#__PURE__*/_jsx(_Row, {
      gutter: 18,
      children: children ? children : renderCore({
        schema: schema.properties,
        rootPath: [].concat(_toConsumableArray(rootPath), [path])
      })
    })
  });
});
